==> dns-1.1-sources.jar: org/nhindirect/dns/provider/ConfigServiceDNSStoreProvider.java <==
/* 
 Copyright (c) 2010, Direct Project
 All rights reserved.

 Authors:
    Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of The Direct Project (directproject.org) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.dns.provider;

import java.net.URL;

import org.nhindirect.dns.ConfigServiceDNSStore;
import org.nhindirect.dns.DNSStore;

import com.google.inject.Provider;

/**
 * Guice provider for creating {@link ConfigServiceDNSStore} instances.
 * @author Greg Meyer
 *
 * @since 1.0
 */
public class ConfigServiceDNSStoreProvider implements Provider<DNSStore>
{
	private final URL configServiceURL;
	
	/**
	 * Provider constructor.
	 * @param configServiceURL  A URL to the location of the DNS configuration service.
	 */
	public ConfigServiceDNSStoreProvider(URL configServiceURL)
	{
		this.configServiceURL = configServiceURL;
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public DNSStore get()
	{
		return new ConfigServiceDNSStore(configServiceURL);
	}
}

==> dns-1.5.2-sources.jar: org/nhindirect/dns/provider/ConfigServiceDNSStoreProvider.java <==
/* 
 Copyright (c) 2010, Direct Project
 All rights reserved.

 Authors:
    Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of The Direct Project (directproject.org) nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.dns.provider;

import java.net.URL;

import org.nhindirect.dns.ConfigServiceDNSStore;
import org.nhindirect.dns.DNSStore;


/**
 * Guice provider for creating {@link ConfigServiceDNSStore} instances.
 * @author Greg Meyer
 *
 * @since 1.0
 */
public class ConfigServiceDNSStoreProvider extends AbstractConfigDNSStoreProvider
{
	
	/**
	 * Provider constructor.
	 * @param configServiceURL  A URL to the location of the DNS configuration service.
	 */
	public ConfigServiceDNSStoreProvider(URL configServiceURL)
	{
		super(configServiceURL);
	}
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	public DNSStore get()
	{
		return new ConfigServiceDNSStore(configServiceURL);
	}
}
